addpath '../routines'
addpath '../examples'

% Abbruchschranke fr das Residuum
tol=1e-8; 

% Maximale Anzahl Iterationen 
kmax=100;  

k=menu('Auswahl der Verfahren zur Bestimmung von F(x)=e^x-sin(x)=0',...
       'Fixpunktiteration Phi_a(x)=x+F(x)',...
       'Fixpunktiteration Phi_b(x)=x-F(x)',...
       'Fixpunktiteration Phi_c(x)=arcsin(e^x)',...
       'Fixpunktiteration Phi_d(x)=ln(sin(x))',...
       'Newtonverfahren fr F(x)=0',...
       'Alle Verfahren',...
       'ENDE');

  
while k<7

      if k==6
	 k=1:5;
      end
      
      l=menu('Startwert', ...
	      '-1/2pi', ...
              '-pi', ...
              '-3/2pi', ...
              '-2pi', ...
	      '-5/2pi', ...
              '-3pi', ...
              '-7/2pi', ...
              '-4pi');
      x0=(-l/2)*pi;

      % Zeit zurcksetzen
      t=zeros(1,5);
      it=zeros(1,5);
      res=zeros(1,5);
      for i=k
	  if i==1
	     t0=clock;
	     [x,ki]=FIXPUNKT('phia',x0,tol,kmax);
	     t(i)=etime(clock,t0);
	     it(i)=ki;
	     res(i)=abs(F(x));
	     fprintf('%d. Phi_a,       x=%12.4e',i,real(x));
	     if ~isreal(x)
		if imag(x)>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(x));
	     end
	     fprintf(', F(x)=%12.4e',real(F(x)));
	     if ~isreal(F(x))
		if imag(F(x))>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(F(x)));
	     end
	     fprintf('\n');
	  elseif i==2
	     t0=clock;
	     [x,ki]=FIXPUNKT('phib',x0,tol,kmax);
	     t(i)=etime(clock,t0);
	     it(i)=ki;
	     res(i)=abs(F(x));
	     fprintf('%d. Phi_b,       x=%12.4e',i,real(x));
	     if ~isreal(x)
		if imag(x)>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(x));
	     end
	     fprintf(', F(x)=%12.4e',real(F(x)));
	     if ~isreal(F(x))
		if imag(F(x))>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(F(x)));
	     end
	     fprintf('\n');
	  elseif i==3
	     t0=clock;
	     [x,ki]=FIXPUNKT('phic',x0,tol,kmax);
	     t(i)=etime(clock,t0);
	     it(i)=ki;
	     res(i)=abs(F(x));
	     fprintf('%d. Phi_c,       x=%12.4e',i,real(x));
	     if ~isreal(x)
		if imag(x)>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(x));
	     end
	     fprintf(', F(x)=%12.4e',real(F(x)));
	     if ~isreal(F(x))
		if imag(F(x))>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(F(x)));
	     end
	     fprintf('\n');
	  elseif i==4
	     t0=clock;
	     [x,ki]=FIXPUNKT('phid',x0,tol,kmax);
	     t(i)=etime(clock,t0);
	     it(i)=ki;
	     res(i)=abs(F(x));
	     fprintf('%d. Phi_d,       x=%12.4e',i,real(x));
	     if ~isreal(x)
		if imag(x)>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(x));
	     end
	     fprintf(', F(x)=%12.4e',real(F(x)));
	     if ~isreal(F(x))
		if imag(F(x))>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(F(x)));
	     end
	     fprintf('\n');
	  elseif i==5
	     t0=clock;
	     [x,ki]=NEWTON1D('F','DF',x0,tol,kmax);
	     t(i)=etime(clock,t0);
	     it(i)=ki;
	     res(i)=abs(F(x));
	     fprintf('%d. Newton,      x=%12.4e',i,real(x));
	     if ~isreal(x)
		if imag(x)>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(x));
	     end
	     fprintf(', F(x)=%12.4e',real(F(x)));
	     if ~isreal(F(x))
		if imag(F(x))>0
		   fprintf('+');
		else
		   fprintf(' ');
		end
		fprintf('%11.4ei',imag(F(x)));
	     end
	     fprintf('\n');
	  end % if-elseif
      end % for i
      fprintf('\n');
      
      figure(1);
      clf
      bar(t);
      title('Zeitbedarf Iterationsverfahren')
      xlabel('1:\Phi_a, 2:\Phi_b, 3:\Phi_c, 4:\Phi_d, 5:Newton') 
      ylabel('Zeit [sec]')

      figure(2);
      clf
      bar(it);
      title(['Anzahl Iterationsschritte (maximal ' num2str(kmax) ')']);
      xlabel('1:\Phi_a, 2:\Phi_b, 3:\Phi_c, 4:\Phi_d, 5:Newton') 
      ylabel('Schritte')
      
      figure(3);
      clf
      bar(log(res)/log(10));
      title('Fehlerbetrachtung mit Hilfe des Residuums |F(x)|')
      xlabel('1:\Phi_a, 2:\Phi_b, 3:\Phi_c, 4:\Phi_d, 5:Newton') 
      ylabel('log_{10}(|F(x)|')
      
      k=menu('Auswahl der Verfahren zur Bestimmung von F(x)=e^x-sin(x)=0',...
             'Fixpunktiteration Phi_a(x)=x+F(x)',...
             'Fixpunktiteration Phi_b(x)=x-F(x)',...
             'Fixpunktiteration Phi_c(x)=arcsin(e^x)',...
             'Fixpunktiteration Phi_d(x)=ln(sin(x))',...
             'Newtonverfahren fr F(x)=0',...
             'Alle Verfahren',...
             'ENDE');
end % while

